@@ -1,9 +1,30 @@
 """StartinBlox commit style parser"""
 
 import re
+import ndebug
 from typing import Tuple
 from semantic_release.errors import UnknownCommitMessageStyleError
-from semantic_release.history.parser_helpers import parse_text_block
+from semantic_release.history.parser_helpers import ParsedCommit
+
+def parse_text_block(text: str) -> Tuple[str, str]:
+    """
+    This will take a text block and return a tuple with body and footer,
+    where footer is defined as the last paragraph.
+
+    :param text: The text string to be divided.
+    :return: A tuple with body and footer,
+    where footer is defined as the last paragraph.
+    """
+    body, footer = '', ''
+    if text:
+        body = text.split('\n\n')[0]
+        if len(text.split('\n\n')) == 2:
+            footer = text.split('\n\n')[1]
+
+    return body.replace('\n', ' '), footer.replace('\n', ' ')
+
+
+debug = ndebug.create(__name__)
 
 re_parser = re.compile(
     r'(?P<type>\w+)'
@@ -13,17 +34,18 @@ re_parser = re.compile(
     re.DOTALL
 )
 
-TYPES = [
+MAJOR_TYPES = [
     'major',
-    'minor',
-    'feature',
-    'update',
-    'bugfix',
-    'ui',
-    'syntax',
-    'other'
 ]
 
+MINOR_TYPES = [
+    'minor',
+]
+
+NOTHING_TYPES = [
+    'cicd',
+    'doc'
+]
 
 def parse_commit_message(message: str) -> Tuple[int, str, str, Tuple[str, str, str]]:
     """
@@ -35,28 +57,30 @@ def parse_commit_message(message: str) -> Tuple[int, str, str, Tuple[str, str, s
     try:
         # default to patch
         level_bump = 1
+        _type = 'other'
 
         # parse message
         parsed = re_parser.match(message)
 
-        # catch type
+        # get the type of commit
         _type = parsed.group('type')
-        if _type not in TYPES:
-            _type = 'other'
 
         # calculate release level
-        if _type == 'major':
-            level_bump = 3
+        if _type in NOTHING_TYPES:
+            level_bump = 0
 
-        elif _type == 'minor':
+        if _type in MINOR_TYPES:
             level_bump = 2
 
+        if _type in MAJOR_TYPES:
+            level_bump = 3
+
+        # get other elements of commit
         subject = parsed.group('subject')
         body, footer = parse_text_block(parsed.group('text'))
 
     except AttributeError:
         # if regex doesn't match make a patch with raw commit message
-        _type = 'other'
         subject = message.split("\n", 1)[0]
         try:
             body, footer = parse_text_block(message.split("\n", 1)[1])
@@ -64,9 +88,18 @@ def parse_commit_message(message: str) -> Tuple[int, str, str, Tuple[str, str, s
             body = ''
             footer = ''
 
-    return (
+    if debug.enabled:
+        debug('parse_commit_message -> ({}, {}, {})'.format(
+            level_bump,
+            _type,
+            (subject, body, footer),
+            ''
+        ))
+
+    return ParsedCommit(
         level_bump,
         _type,
         '',
-        (subject, body, footer)
-    )
+        (subject, body, footer),
+        ''
+    )
\ No newline at end of file
